@@ -32,9 +32,15 @@ FAILEDOPERATION_ASYNCEVENTSTATUS = 'FailedOperation.AsyncEventStatus'
 # 登录信息验证失败，token 验证失败。
 FAILEDOPERATION_AUTHFAILURE = 'FailedOperation.AuthFailure'
 
+# 调用 NetDeploy 失败。
+FAILEDOPERATION_CALLNETDEPLOYFAILED = 'FailedOperation.CallNetDeployFailed'
+
 # 请求role信息失败。
 FAILEDOPERATION_CALLROLEFAILED = 'FailedOperation.CallRoleFailed'
 
+# CLS服务未注册。
+FAILEDOPERATION_CLSSERVICEUNREGISTERED = 'FailedOperation.ClsServiceUnregistered'
+
 # CopyAsyncRun 传参异常。
 FAILEDOPERATION_COPYASYNCRUN = 'FailedOperation.CopyAsyncRun'
 
@@ -188,6 +194,9 @@ INTERNALERROR_EXCEPTION = 'InternalError.Exception'
 # 内部服务错误。
 INTERNALERROR_GETROLEERROR = 'InternalError.GetRoleError'
 
+# 获取sts票据信息失败。
+INTERNALERROR_GETSTSTOKENFAILED = 'InternalError.GetStsTokenFailed'
+
 # 内部系统错误。
 INTERNALERROR_SYSTEM = 'InternalError.System'
 
